package javathreadsprezi;

import java.awt.BorderLayout;
import java.awt.EventQueue;
import java.awt.HeadlessException;
import java.awt.event.ActionEvent;
import java.io.IOException;
import java.io.InputStream;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.List;
import java.util.Scanner;
import java.util.concurrent.ExecutionException;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.SwingWorker;

class JavaThreadsDemo7 implements JavaThreadsDemoable {

    @Override
    public void doDemo() {
        EventQueue.invokeLater(new Runnable() {
            @Override
            public void run() {
                new HtmlFrame().setVisible(true);
            }
        });
    }
}

class HtmlFrame extends JFrame {

    private URL url;
    private JTextArea htmlSource;

    public HtmlFrame() throws HeadlessException {
        try {
            url = new URL("http://www.elte.hu/");
        } catch (MalformedURLException ex) {
            return;
        }
        setTitle(url.toString());
        setSize(600, 400);
        setDefaultCloseOperation(EXIT_ON_CLOSE);
        htmlSource = new JTextArea();
        getContentPane().add(new JScrollPane(htmlSource), BorderLayout.CENTER);
        getContentPane().add(new JButton(loadHtmlAction), BorderLayout.NORTH);
    }
    private Action loadHtmlAction = new AbstractAction("Load") {
        @Override
        public void actionPerformed(ActionEvent e) {
            htmlLoader = new HtmlLoader();
            htmlLoader.execute();
        }
    };
    private HtmlLoader htmlLoader;

    private class HtmlLoader extends SwingWorker<Void, String> {

        @Override
        protected Void doInBackground() throws Exception {
            Scanner scanner;
            try {
                InputStream stream = url.openStream();
                scanner = new Scanner(stream);
            } catch (IOException ex) {
                return null;
            }
            while (scanner.hasNextLine()) {
                final String line = scanner.nextLine();
                publish(line, "\n");
            }
            scanner.close();
            return null;
        }

        @Override
        protected void process(List<String> chunks) {
            for (String chunk : chunks) {
                htmlSource.append(chunk);
            }
        }

    }
}